@@ -1,4 +1,5 @@
 import ckan.authz as authz
+from ckan.common import asbool
 from ckan import logic
 import ckan.plugins.toolkit as toolkit
 
@@ -7,10 +8,6 @@ from . import helpers as dcor_helpers
 
 def dataset_purge(context, data_dict):
     """Only allow deletion of deleted datasets"""
-    # user must be logged-in
-    ac = login_user(context)
-    if not ac["success"]:
-        return ac
     # original auth function
     # (usually, only sysadmins are allowed to purge, so we test against
     # package_update)
@@ -27,7 +24,7 @@ def dataset_purge(context, data_dict):
     }
     package_dict = logic.get_action('package_show')(
         show_context,
-        {'id': logic.get_or_bust(data_dict, 'id')})
+        {'id': get_package_id(context, data_dict)})
     state = package_dict.get('state')
     if state != "deleted":
         return {"success": False,
@@ -40,29 +37,20 @@ def deny(context, data_dict):
             'msg': "Only admins may do so."}
 
 
-def login_user(context, data_dict=None):
-    # Get the user name of the logged-in user.
-    user = context['user']
-    convert_user_name_or_id_to_id = toolkit.get_converter(
-        'convert_user_name_or_id_to_id')
-    try:
-        # check whether the user is logged-in
-        convert_user_name_or_id_to_id(user, context)
-    except toolkit.Invalid:
-        # The user doesn't exist (e.g. they're not logged-in).
-        return {'success': False,
-                'msg': 'You must be logged-in.'}
-
-    # All users are allowed to do this
-    return {'success': True}
+def get_package_id(context, data_dict):
+    """Convenience function that extracts the package_id"""
+    package = context.get('package')
+    if package:
+        # web
+        package_id = package.id
+    else:
+        package_id = logic.get_or_bust(data_dict, 'id')
+    convert_package_name_or_id_to_id = toolkit.get_converter(
+        'convert_package_name_or_id_to_id')
+    return convert_package_name_or_id_to_id(package_id, context)
 
 
 def package_create(context, data_dict):
-    # user must be logged-in
-    ac = login_user(context)
-    if not ac["success"]:
-        return ac
-
     user = context['user']
     # If a group is given, check whether the user has the necessary permissions
     check_group = logic.auth.create._check_group_auth(context, data_dict)
@@ -72,22 +60,29 @@ def package_create(context, data_dict):
                        + 'these collections'}
 
     # Are we allowed to add a dataset to the given organization?
-    org_id = logic.get_or_bust(data_dict, 'owner_org')
-    if not authz.has_user_permission_for_group_or_org(
-            org_id, user, 'create_dataset'):
-        return {'success': False,
-                'msg': 'User {} not authorized to add datasets '.format(user)
-                       + 'to circle {}!'.format(org_id)}
+    org_id = None if data_dict is None else data_dict.get('owner_org', None)
+    if org_id is None:
+        # No organization was given. This means that we just have to check
+        # whether the user can create packages in general. Since the user
+        # is logged-in, he can do that.
+        # elaboration:
+        # - if `data_dict` is None, we currently want to create a new dataset
+        #   (/dataset/new)
+        # - if `data_dict["owner_org"] is None, we currently want to view
+        #   the datasets (/dataset)
+        pass
+    else:
+        if not authz.has_user_permission_for_group_or_org(
+                org_id, user, 'create_dataset'):
+            return {'success': False,
+                    'msg': 'User {} not authorized to add '.format(user)
+                           + 'datasets to circle {}!'.format(org_id)}
 
     return {"success": True}
 
 
 def package_delete(context, data_dict):
     """Only allow deletion of draft datasets"""
-    # user must be logged-in
-    ac = login_user(context)
-    if not ac["success"]:
-        return ac
     # original auth function
     ao = logic.auth.update.package_update(context, data_dict)
     if not ao["success"]:
@@ -102,7 +97,7 @@ def package_delete(context, data_dict):
     }
     package_dict = logic.get_action('package_show')(
         show_context,
-        {'id': logic.get_or_bust(data_dict, 'id')})
+        {'id': get_package_id(context, data_dict)})
     state = package_dict.get('state')
     if state != "draft":
         return {"success": False,
@@ -111,15 +106,14 @@ def package_delete(context, data_dict):
 
 
 def package_update(context, data_dict=None):
-    # user must be logged-in
-    ac = login_user(context)
-    if not ac["success"]:
-        return ac
     # original auth function
     ao = logic.auth.update.package_update(context, data_dict)
     if not ao["success"]:
         return ao
 
+    if data_dict is None:
+        data_dict = {}
+
     # get the current package dict
     show_context = {
         'model': context['model'],
@@ -127,30 +121,31 @@ def package_update(context, data_dict=None):
         'user': context['user'],
         'auth_user_obj': context['auth_user_obj'],
     }
-    package_dict = logic.get_action('package_show')(
+    pkg_dict = logic.get_action('package_show')(
         show_context,
-        {'id': logic.get_or_bust(data_dict, 'id')})
+        {'id': get_package_id(context, data_dict)})
     # do not allow switching to a more restrictive license
     if "license_id" in data_dict:
-        allowed = dcor_helpers.get_valid_licenses(package_dict["license_id"])
+        allowed = dcor_helpers.get_valid_licenses(pkg_dict["license_id"])
         if data_dict["license_id"] not in allowed:
             return {'success': False,
                     'msg': 'Cannot switch to more-restrictive license'}
     # do not allow setting state from "active" to "draft"
-    if package_dict["state"] != "draft" and data_dict.get("state") == "draft":
+    if pkg_dict["state"] != "draft" and data_dict.get("state") == "draft":
         return {'success': False,
                 'msg': 'Changing dataset state to draft not allowed'}
     # do not allow setting the visibility from public to private
-    if not package_dict["private"] and data_dict.get("private", False):
+    if not pkg_dict["private"] and asbool(data_dict.get("private", False)):
+        assert isinstance(pkg_dict["private"], bool)
         return {'success': False,
                 'msg': 'Changing visibility to private not allowed'}
     # do not allow changing some of the keys
     prohibited_keys = ["name"]
     invalid = {}
     for key in data_dict:
-        if (key in package_dict
+        if (key in pkg_dict
             and key in prohibited_keys
-                and data_dict[key] != package_dict[key]):
+                and data_dict[key] != pkg_dict[key]):
             invalid[key] = data_dict[key]
     if invalid:
         return {'success': False,
@@ -160,10 +155,6 @@ def package_update(context, data_dict=None):
 
 
 def resource_create(context, data_dict=None):
-    # user must be logged-in
-    ac = login_user(context)
-    if not ac["success"]:
-        return ac
     # original auth function
     ao = logic.auth.create.resource_create(context, data_dict)
     if not ao["success"]:
@@ -190,10 +181,6 @@ def resource_create(context, data_dict=None):
 
 
 def resource_update(context, data_dict=None):
-    # user must be logged-in
-    ac = login_user(context)
-    if not ac["success"]:
-        return ac
     # original auth function
     ao = logic.auth.update.resource_update(context, data_dict)
     if not ao["success"]:
@@ -209,11 +196,7 @@ def resource_update(context, data_dict=None):
     resource_dict = logic.get_action('resource_show')(
         show_context,
         {'id': logic.get_or_bust(data_dict, 'id')})
-    # convert to package id (otherwise the check below might fail)
-    convert_package_name_or_id_to_id = toolkit.get_converter(
-        'convert_package_name_or_id_to_id')
-    data_dict["package_id"] = convert_package_name_or_id_to_id(
-            logic.get_or_bust(data_dict, "package_id"), context)
+    data_dict["package_id"] = get_package_id(context, data_dict)
     # only allow updating the description
     allowed_keys = ["description"]
     invalid = {}
